@@ -37,7 +37,10 @@ class ShipmentIn:
         for key, parcel in groupby(lines, key=keyfunc):
             weight = 0
             for line in parcel:
-                if line.product and line.quantity and line.uom:
+                if (line.product
+                        and line.quantity
+                        and line.uom
+                        and line.product.weight):
                     quantity = Uom.compute_qty(line.uom, line.quantity,
                         line.product.default_uom, round=False)
                     weight += Uom.compute_qty(line.product.weight_uom,
@@ -75,7 +78,10 @@ class ShipmentOut:
         for key, parcel in groupby(lines, key=keyfunc):
             weight = 0
             for line in parcel:
-                if line.product and line.quantity and line.uom:
+                if (line.product
+                        and line.quantity
+                        and line.uom
+                        and line.product.weight):
                     quantity = Uom.compute_qty(line.uom, line.quantity,
                         line.product.default_uom, round=False)
                     weight += Uom.compute_qty(line.product.weight_uom,
